@@ -13,14 +13,26 @@ class MobileFilter(BaseFilter):
     """手机号过滤器"""
     error_code = 565
 
+    def fmt_error_message(self, _):
+        """ 格式化错误消息
+        """
+        return "%s字段不符合手机号格式!" % self.key
+
+    def filter_required(self):
+        """ 检查过滤器是否必须执行
+        """
+        if not self.rule.required and self.value is None:
+            return False
+
+        if not self.rule.mobile:
+            return False
+
+        return True
+
     def __call__(self, *args, **kwargs):
         super(MobileFilter, self).__call__()
 
-        if self.rule.allow_empty and self.value == self.rule.default:
-            return self.value
-
-        if self.rule.mobile:
-            if not MobileRegexp()(self.value):
-                raise ParamsValueError(self.error_code, filter=self)
+        if not MobileRegexp()(self.value):
+            raise ParamsValueError(self.error_code, filter=self)
 
         return self.value
